==> open-xchange-server_6.12.0.0.orig.tar.gz: open-xchange-server-6.12.0.0/src/com/openexchange/server/osgi/PublicationTargetDiscoveryServiceTrackerCustomizer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.server.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.publish.PublicationTargetDiscoveryService;
import com.openexchange.server.services.ServerServiceRegistry;

/**
 * {@link PublicationTargetDiscoveryServiceTrackerCustomizer} - The {@link ServiceTrackerCustomizer customizer} for
 * {@link PublicationTargetDiscoveryService}.
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class PublicationTargetDiscoveryServiceTrackerCustomizer implements ServiceTrackerCustomizer {

    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PublicationTargetDiscoveryServiceTrackerCustomizer.class);

    private final BundleContext context;

    private final int ranking;

    /**
     * Initializes a new {@link PublicationTargetDiscoveryServiceTrackerCustomizer}.
     * 
     * @param context The bundle context
     */
    public PublicationTargetDiscoveryServiceTrackerCustomizer(final BundleContext context) {
        super();
        this.context = context;
        ranking = -1;
    }

    public Object addingService(final ServiceReference reference) {
        final int refRanking = getServiceReferenceRanking(reference);
        if (refRanking <= ranking) {
            // Nothing to track if ranking is less than or equal to current ranking
            return null;
        }
        final PublicationTargetDiscoveryService addedService = (PublicationTargetDiscoveryService) context.getService(reference);
        ServerServiceRegistry.getInstance().addService(PublicationTargetDiscoveryService.class, addedService);
        return addedService;
    }

    public void modifiedService(final ServiceReference reference, final Object service) {
        // Nothing to do
    }

    public void removedService(final ServiceReference reference, final Object service) {
        if (null != service) {
            try {
                ServerServiceRegistry.getInstance().removeService(PublicationTargetDiscoveryService.class);
            } finally {
                context.ungetService(reference);
            }
        }
    }

    private static int getServiceReferenceRanking(final ServiceReference reference) {
        final Object property = reference.getProperty(org.osgi.framework.Constants.SERVICE_RANKING);
        if (property == null) {
            return 0;
        }
        if (Integer.class.isInstance(property)) {
            return ((Integer) property).intValue();
        }
        try {
            return Integer.parseInt(property.toString());
        } catch (final NumberFormatException e) {
            LOG.error("Service ranking cannot be parsed to an integer: " + property.toString(), e);
            return 0;
        }
    }

}

==> open-xchange-server_6.20.8.0.orig.tar.gz: open-xchange-server-6.20.8.0/src/com/openexchange/server/osgi/PublicationTargetDiscoveryServiceTrackerCustomizer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.server.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.publish.PublicationTargetDiscoveryService;
import com.openexchange.server.services.ServerServiceRegistry;

/**
 * {@link PublicationTargetDiscoveryServiceTrackerCustomizer} - The {@link ServiceTrackerCustomizer customizer} for
 * {@link PublicationTargetDiscoveryService}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class PublicationTargetDiscoveryServiceTrackerCustomizer implements ServiceTrackerCustomizer {

    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PublicationTargetDiscoveryServiceTrackerCustomizer.class));

    private final BundleContext context;

    private final int ranking;

    /**
     * Initializes a new {@link PublicationTargetDiscoveryServiceTrackerCustomizer}.
     *
     * @param context The bundle context
     */
    public PublicationTargetDiscoveryServiceTrackerCustomizer(final BundleContext context) {
        super();
        this.context = context;
        ranking = -1;
    }

    public Object addingService(final ServiceReference reference) {
        final int refRanking = getServiceReferenceRanking(reference);
        if (refRanking <= ranking) {
            // Nothing to track if ranking is less than or equal to current ranking
            return null;
        }
        final PublicationTargetDiscoveryService addedService = (PublicationTargetDiscoveryService) context.getService(reference);
        ServerServiceRegistry.getInstance().addService(PublicationTargetDiscoveryService.class, addedService);
        return addedService;
    }

    public void modifiedService(final ServiceReference reference, final Object service) {
        // Nothing to do
    }

    public void removedService(final ServiceReference reference, final Object service) {
        if (null != service) {
            try {
                ServerServiceRegistry.getInstance().removeService(PublicationTargetDiscoveryService.class);
            } finally {
                context.ungetService(reference);
            }
        }
    }

    private static int getServiceReferenceRanking(final ServiceReference reference) {
        final Object property = reference.getProperty(org.osgi.framework.Constants.SERVICE_RANKING);
        if (property == null) {
            return 0;
        }
        if (Integer.class.isInstance(property)) {
            return ((Integer) property).intValue();
        }
        try {
            return Integer.parseInt(property.toString());
        } catch (final NumberFormatException e) {
            LOG.error("Service ranking cannot be parsed to an integer: " + property.toString(), e);
            return 0;
        }
    }

}
